==> android-aihelp-aar-3.1.7-sources.jar: net/aihelp/db/bot/ConversationSQLiteHelper.java <==
package net.aihelp.db.bot;

import android.content.Context;

import net.aihelp.config.AIHelpContext;
import net.aihelp.core.db.BaseSQLiteHelper;
import net.aihelp.core.db.DropAndCreateDatabaseHelper;
import net.aihelp.core.db.IDatabaseContract;
import net.aihelp.core.db.IMigrateContract;
import net.aihelp.db.bot.tables.ElvaBotTable;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;


public class ConversationSQLiteHelper extends BaseSQLiteHelper {

    private static final String CREATE_ELVA_TABLE = "CREATE TABLE elva_bot (_id INTEGER PRIMARY KEY AUTOINCREMENT, uid TEXT NOT NULL, app_id TEXT NOT NULL, app_server TEXT NOT NULL, time_stamp INTEGER UNIQUE,raw_response TEXT NOT NULL);";

    private ConversationSQLiteHelper(Context context, IDatabaseContract contract) {
        super(context, contract);
    }

    public static ConversationSQLiteHelper getInstance() {
        return ConversationSQLiteHelper.LazyHolder.INSTANCE;
    }

    private static class LazyHolder {

        static final ConversationSQLiteHelper INSTANCE = new ConversationSQLiteHelper(
                AIHelpContext.getInstance().getContext(), new IDatabaseContract() {

            @Override
            public int getDatabaseVersion() {
                return 1;
            }

            @Override
            public String getDatabaseName() {
                return "ConversationDatabase";
            }

            @Override
            public List<String> getCreateTableQueries() {
                return Collections.singletonList(CREATE_ELVA_TABLE);
            }

            @Override
            public List<IMigrateContract> getMigratorsForUpgrade(int oldDbVersion) {
                List<IMigrateContract> contractList = new ArrayList<>();
                contractList.add(new DropAndCreateDatabaseHelper(this));
                return contractList;
            }

            @Override
            public List<String> getTableNames() {
                return Collections.singletonList(ElvaBotTable.TABLE_NAME);
            }

            @Override
            public String getTag() {
                return "AIHelp_DB_CONVERSATION";
            }

        });
    }

}

==> android-aihelp-aar-3.5.4-sources.jar: net/aihelp/db/bot/ConversationSQLiteHelper.java <==
package net.aihelp.db.bot;

import android.content.Context;

import net.aihelp.config.AIHelpContext;
import net.aihelp.core.db.BaseSQLiteHelper;
import net.aihelp.core.db.DropAndCreateDatabaseHelper;
import net.aihelp.core.db.IDatabaseContract;
import net.aihelp.core.db.IMigrateContract;
import net.aihelp.db.bot.tables.ElvaBotTable;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;


public class ConversationSQLiteHelper extends BaseSQLiteHelper {

    private static final String CREATE_ELVA_TABLE = "CREATE TABLE elva_bot (_id INTEGER PRIMARY KEY AUTOINCREMENT, uid TEXT NOT NULL, app_id TEXT NOT NULL, app_server TEXT NOT NULL, time_stamp INTEGER UNIQUE,raw_response TEXT NOT NULL);";

    private ConversationSQLiteHelper(Context context, IDatabaseContract contract) {
        super(context, contract);
    }

    public static ConversationSQLiteHelper getInstance() {
        return ConversationSQLiteHelper.LazyHolder.INSTANCE;
    }

    private static class LazyHolder {

        static final ConversationSQLiteHelper INSTANCE = new ConversationSQLiteHelper(
                AIHelpContext.getInstance().getContext().getApplicationContext(), new IDatabaseContract() {

            @Override
            public int getDatabaseVersion() {
                return 1;
            }

            @Override
            public String getDatabaseName() {
                return "ConversationDatabase";
            }

            @Override
            public List<String> getCreateTableQueries() {
                return Collections.singletonList(CREATE_ELVA_TABLE);
            }

            @Override
            public List<IMigrateContract> getMigratorsForUpgrade(int oldDbVersion) {
                List<IMigrateContract> contractList = new ArrayList<>();
                contractList.add(new DropAndCreateDatabaseHelper(this));
                return contractList;
            }

            @Override
            public List<String> getTableNames() {
                return Collections.singletonList(ElvaBotTable.TABLE_NAME);
            }

            @Override
            public String getTag() {
                return "AIHelp_DB_CONVERSATION";
            }

        });
    }

}
